@@ -5,10 +5,6 @@ Created on 2015-7-9
 @author: cheng.li
 """
 
-__all__ = ['__version__', 'API', 'DateUtilities', 'Enums', 'Env', 'Math', 'PricingEngines', 'Risk', 'AlgoTrading']
-
-__version__ = "0.3.4"
-
 import PyFin.API as API
 import PyFin.DateUtilities as DateUtilities
 import PyFin.Enums as Enums
@@ -16,4 +12,12 @@ import PyFin.Env as Env
 import PyFin.Math as Math
 import PyFin.PricingEngines as PricingEngines
 import PyFin.Analysis as Analysis
-import PyFin.AlgoTrading as AlgoTrading
+
+__all__ = ['__version__',
+           'API',
+           'DateUtilities',
+           'Enums', 'Env',
+           'Math',
+           'PricingEngines']
+
+__version__ = "0.3.5"
